## Estore base classes

THIS IS AN EARLY ALPHA

This is a common dependency code for both, estore-client and estore-server.

## Installing
From PyPi

```bash
pip3 install estore-base
```

From GitHub

```bash
git clone git@github.com:lostwire/estore-base.git
cd estore-base
git install .
```
